==> raven-clj-0.1.0.jar: raven_clj/ring.clj <==
(ns raven-clj.ring
  "Ring utility functions."
  (:require [raven-clj.core :as raven]
            [ring.util.request :refer [request-url]]
            [ring.util.response :as response]))

(defn- request->http
  "Converts a Ring request into an HTTP interface for an event."
  [req]
  {:url          (request-url req)
   :method       (:request-method req)
   :data         (:params req)
   :query_string (:query-string req "")
   :headers      (:headers req)
   :env          {:session      (-> req :session pr-str)
                  "REMOTE_ADDR" (:remote-addr req)}})

(defn- request->user
  "Converts a Ring request into a User interface for an event."
  [req]
  {:ip_address (:remote-addr req)})

(defn- request->event
  "Given a request and an exception, returns the Sentry event to be sent."
  [req e]
  {:throwable  e
   :interfaces {:request (request->http req)
                :user    (request->user req)}})

(defn- default-error
  "A very bare-bones error message. Ignores the request and exception."
  [_ _]
  (-> (str "<html><head><title>Error</title></head>"
           "<body><p>Internal Server Error</p></body></html>")
      (response/content-type "text/html")
      (response/status 500)))

(defn wrap-report-exceptions
  "Wraps the given handler in error reporting.

  Optionally takes three functions:

  * `:preprocess-fn`, which is passed the request
  * `:postprocess-fn`, which is passed the request and the Sentry event
  * `:error-fn`, which is passed the request and the thrown exception and
    returns an appropriate Ring response
  "
  [handler dsn {:keys [preprocess-fn postprocess-fn error-fn]
                :or   {preprocess-fn  identity
                       postprocess-fn (comp second list)
                       error-fn       default-error}}]
  (fn [req]
    (try
      (handler req)
      (catch Throwable e
        (-> req
            preprocess-fn
            (request->event e)
            (->> (postprocess-fn req)
                 (raven/send-event dsn)))
        (error-fn req e)))))

==> raven-clj-0.1.0-20160906.224627-1.jar: raven_clj/ring.clj <==
(ns raven-clj.ring
  "Ring utility functions."
  (:require [raven-clj.core :as raven]
            [ring.util.request :refer [request-url]]
            [ring.util.response :as response]))

(defn- request->http
  "Converts a Ring request into an HTTP interface for an event."
  [req]
  {:url          (request-url req)
   :method       (:request-method req)
   :data         (:params req)
   :query_string (:query-string req "")
   :headers      (:headers req)
   :env          {:session      (-> req :session pr-str)
                  "REMOTE_ADDR" (:remote-addr req)}})

(defn- request->user
  "Converts a Ring request into a User interface for an event."
  [req]
  {:ip_address (:remote-addr req)})

(defn- request->event
  "Given a request and an exception, returns the Sentry event to be sent."
  [req e]
  {:throwable  e
   :interfaces {:http (request->http req)
                :user (request->user req)}})

(defn- default-error
  "A very bare-bones error message. Ignores the request and exception."
  [_ _]
  (-> (str "<html><head><title>Error</title></head>"
           "<body><p>Internal Server Error</p></body></html>")
      (response/content-type "text/html")
      (response/status 500)))

(defn wrap-report-exceptions
  "Wraps the given handler in error reporting.

  Optionally takes three functions:

  * `:preprocess-fn`, which is passed the request
  * `:postprocessn-fn`, which is passed the Sentry event
  * `:error-fn`, which is passed the request and the thrown exception and
    returns an appropriate Ring response
  "
  [handler dsn {:keys [preprocess-fn postprocess-fn error-fn]
                :or   {preprocess-fn  identity
                       postprocess-fn identity
                       error-fn       default-error}}]
  (fn [req]
    (try
      (handler req)
      (catch Throwable e
        (-> req
            preprocess-fn
            (request->event e)
            postprocess-fn
            (->> (raven/send-event dsn)))
        (error-fn req e)))))
